<!DOCTYPE html>
<html lang="en" class="uk-height-1-1">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta http-equiv="refresh" content="10;http://blank.org/"/>
    <title>Comitup</title>
    <link rel="icon" href="img/favicon.ico">
    <!-- CSS FILES -->
    <link rel="stylesheet" type="text/css" href="css/uikit.css">
</head>
<body class="uk-height-1-1">
<div class="uk-flex uk-flex-center uk-flex-middle">
    <div class="uk-position-bottom-center uk-position-small">
        <span class="uk-text-small uk-text-muted">Comitup - Built with <a href="https://github.com/davesteele/comitup" title="Comitup" target="_blank" data-uk-tooltip>ComitUp</a></span>
    </div>
    <div class="uk-width-large uk-padding-small">
        <div class="uk-width-1-1 uk-text-center">
            <span class="" uk-icon="icon: world; ratio: 5"></span>
            <p class="uk-text-large">Connecting to Wifi</p>
        </div>

        <div class="uk-margin">
            <div class="uk-width-1-1 uk-text-center">
                <p>
                    Connection to {{ ssid }} is being attempted.
                </p>
            </div>
        </div>
    </div>
</div>

<!-- JS FILES -->
<script src="js/uikit"></script>
<script src="js/uikit-icons"></script>
